/****************************************************************
 *								*
 * Copyright (c) 2001-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef SUSPSIGS_HANDLER_H_INCLUDED
#define SUSPSIGS_HANDLER_H_INCLUDED

void suspsigs_handler(int sig, siginfo_t *info, void *context);

#endif
